PLS
===========

![image](icons/PLS.png)

A dummy widget that greets the world.

Signals
-------

- Data 
- Preprocessors

**Outputs**:

- Learner
- Model

Description
-----------

This widget creates a PLS learner or PLS model. The GUI can generate a PRESS plot to determine the optimum number of components to keep.
